<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :isShowHide="true"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="wareHouseTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import { fetchList, delObj } from '@/api/warehouse/warehouse'
import TableForm from './warehouse-form'
import { mapGetters } from 'vuex'
import { remote } from '../../../api/admin/dict'
import ttable from '@/views/common/ztt-table.vue'
export default {
  data() {
    return {
      ajaxFun: fetchList,
      warehouseTypeOptions: [],
      mulWarehouse: [],
      multipleSelection: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: true,
        url: '/mes/warehouse/uploadExcel'
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: true, // 高级查询按钮
        defaultOrderBy: { column: 'createTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 仓库编号
          {
            minWidth: '140',
            prop: 'warehouseNo',
            label: '仓库编号',
            sort: true,
            isTrue: true,
            formatter: (row, column, cellValue) => {
              return cellValue
            },
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 仓库名称
          {
            minWidth: '120',
            prop: 'warehouseName',
            label: '仓库名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 仓库描述
          {
            minWidth: '140',
            prop: 'warehouseDesc',
            label: '仓库描述',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 仓库类型
          {
            minWidth: '120',
            prop: 'warehouseType',
            label: '仓库类型',
            sort: true,
            formatter: this.WarehouseType,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 工厂
          {
            minWidth: '200',
            prop: 'factoryNo',
            label: '工厂',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 仓库地址
          {
            minWidth: '140',
            prop: 'warehouseAddr',
            label: '仓库地址',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 仓库地图
          {
            minWidth: '120',
            prop: 'url',
            label: '仓库地图',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 仓库状态
          {
            minWidth: '200',
            prop: 'warehouseStatus',
            label: '仓库状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getWarehouseStatusOptionList()
            },
            formatter: (row, column, cellValue) => {
              return cellValue == 1 ? '启用' : '停用'
            }
          },
          // 备注
          {
            minWidth: '140',
            prop: 'warehouseRemark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 创建时间
          {
            minWidth: '200',
            width: '300',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false,
      warehouseOptionList: [
        {
          value: 1,
          label: '启用'
        },
        {
          value: 0,
          label: '停用'
        }
      ]
    }
  },
  components: {
    ttable,
    TableForm
  },
  created() {
    this.getWarehouseTypeCache('storehouse_type') // 获取定时任务运行时状态
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 选中仓库行
    handleSelectionChange(val) {
      this.mulWarehouse = val
    },
    /**
     * 获取字典显示名称并缓存
     */
    getWarehouseTypeCache(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.warehouseTypeOptions = _data
        }
      })
    },
    /**
     * 获取字典定时任务执行状态字典值显示名称
     */
    WarehouseType(row, column, cellValue) {
      this.warehouseTypeOptions.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 获取数据列表
    getData() {
      this.$refs.wareHouseTable.getDataList()
    },
    getWarehouseStatusOptionList() {
      return this.warehouseOptionList
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除仓库名称为' + row.warehouseName, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    }
  }
}
</script>
